@@ -7,6 +7,7 @@
 ### dependencies: library(sets)
 ###
 ### 2008-04-24: created
+### 2017-12-13: Change return class
 ###
 
 kbase <- function(x) {
@@ -20,11 +21,12 @@ kbase <- function(x) {
    }
 
    ### compute base
-   atoms <- katoms(x, items=as.set(unique(unlist(x))))
-   base <- do.call(c,atoms)
-   names(base) <- NULL
-   class(base) <- unique(c("kstructure", class(base)))
+   atoms <- katoms(x, kdomain(x))
+   names(atoms) <- NULL
+   base <- as.set(unlist(atoms, recursive=FALSE))
+   class(base) <- c("kbase", class(base))
 
    ### return base
    base
 }
+
